@@ -72,6 +72,7 @@ type Segment struct {
 	Enabled                bool           `json:"-" toml:"-"`
 	Newline                bool           `json:"newline,omitempty" toml:"newline,omitempty"`
 	InvertPowerline        bool           `json:"invert_powerline,omitempty" toml:"invert_powerline,omitempty"`
+	restored               bool           `json:"-" toml:"-"`
 }
 
 func (segment *Segment) Name() string {
@@ -202,6 +203,7 @@ func (segment *Segment) hasCache() bool {
 func (segment *Segment) isToggled() bool {
 	toggles, OK := segment.env.Session().Get(cache.TOGGLECACHE)
 	if !OK || len(toggles) == 0 {
+		log.Debug("no toggles found")
 		return false
 	}
 
@@ -223,6 +225,7 @@ func (segment *Segment) restoreCache() bool {
 
 	data, OK := segment.env.Session().Get(segment.cacheKey())
 	if !OK {
+		log.Debug("no cache found for segment: ", segment.Name())
 		return false
 	}
 
@@ -234,11 +237,15 @@ func (segment *Segment) restoreCache() bool {
 	segment.Enabled = true
 	template.Cache.AddSegmentData(segment.Name(), segment.writer)
 
+	log.Debug("restored segment from cache: ", segment.Name())
+
+	segment.restored = true
+
 	return true
 }
 
 func (segment *Segment) setCache() {
-	if !segment.hasCache() {
+	if segment.restored || !segment.hasCache() {
 		return
 	}
 
