@@ -10,9 +10,14 @@ import (
 	"github.com/charmbracelet/bubbles/spinner"
 	tea "github.com/charmbracelet/bubbletea"
 	"github.com/charmbracelet/lipgloss"
+	cache_ "github.com/jandedobbeleer/oh-my-posh/src/cache"
+	"github.com/jandedobbeleer/oh-my-posh/src/terminal"
 )
 
-var program *tea.Program
+var (
+	program *tea.Program
+	cache   cache_.Cache
+)
 
 const listHeight = 14
 
@@ -46,8 +51,6 @@ func (d itemDelegate) Render(w io.Writer, m list.Model, index int, listItem list
 		return
 	}
 
-	str := fmt.Sprintf(i.Name)
-
 	fn := itemStyle.Render
 	if index == m.Index() {
 		fn = func(s ...string) string {
@@ -55,7 +58,7 @@ func (d itemDelegate) Render(w io.Writer, m list.Model, index int, listItem list
 		}
 	}
 
-	fmt.Fprint(w, fn(str))
+	fmt.Fprint(w, fn(i.Name))
 }
 
 const (
@@ -69,13 +72,14 @@ const (
 )
 
 type main struct {
-	spinner  spinner.Model
-	list     *list.Model
-	system   bool
-	font     string
-	state    state
 	err      error
+	list     *list.Model
+	font     string
 	families []string
+	spinner  spinner.Model
+	state    state
+	system   bool
+	ttf      bool
 }
 
 func (m *main) buildFontList(nerdFonts []*Asset) {
@@ -113,24 +117,27 @@ func downloadFontZip(location string) {
 		program.Send(errMsg(err))
 		return
 	}
+
 	program.Send(zipMsg(zipFile))
 }
 
-func installLocalFontZIP(zipFile string, user bool) {
+func installLocalFontZIP(zipFile string, user, ttf bool) {
 	data, err := os.ReadFile(zipFile)
 	if err != nil {
 		program.Send(errMsg(err))
 		return
 	}
-	installFontZIP(data, user)
+
+	installFontZIP(data, user, ttf)
 }
 
-func installFontZIP(zipFile []byte, user bool) {
-	families, err := InstallZIP(zipFile, user)
+func installFontZIP(zipFile []byte, user, ttf bool) {
+	families, err := InstallZIP(zipFile, user, ttf)
 	if err != nil {
 		program.Send(errMsg(err))
 		return
 	}
+
 	program.Send(successMsg(families))
 }
 
@@ -153,11 +160,12 @@ func (m *main) Init() tea.Cmd {
 
 	defer func() {
 		if isLocalZipFile() {
-			go installLocalFontZIP(m.font, m.system)
+			go installLocalFontZIP(m.font, m.system, m.ttf)
 			return
 		}
 		go getFontsList()
 	}()
+
 	s := spinner.New()
 	s.Spinner = spinner.Dot
 	s.Style = lipgloss.NewStyle().Foreground(lipgloss.Color("170"))
@@ -166,6 +174,7 @@ func (m *main) Init() tea.Cmd {
 	if isLocalZipFile() {
 		m.state = unzipFont
 	}
+
 	return m.spinner.Tick
 }
 
@@ -206,12 +215,32 @@ func (m *main) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			}()
 			m.spinner.Spinner = spinner.Globe
 			return m, m.spinner.Tick
+
+		case "up", "k":
+			if m.list != nil {
+				if m.list.Index() == 0 {
+					m.list.Select(len(m.list.Items()) - 1)
+				} else {
+					m.list.Select(m.list.Index() - 1)
+				}
+			}
+			return m, nil
+
+		case "down", "j":
+			if m.list != nil {
+				if m.list.Index() == len(m.list.Items())-1 {
+					m.list.Select(0)
+				} else {
+					m.list.Select(m.list.Index() + 1)
+				}
+			}
+			return m, nil
 		}
 
 	case zipMsg:
 		m.state = installFont
 		defer func() {
-			go installFontZIP(msg, m.system)
+			go installFontZIP(msg, m.system, m.ttf)
 		}()
 		m.spinner.Spinner = spinner.Dot
 		return m, m.spinner.Tick
@@ -244,36 +273,49 @@ func (m *main) View() string {
 	if m.err != nil {
 		return textStyle.Render(m.err.Error())
 	}
+
 	switch m.state {
 	case getFonts:
-		return textStyle.Render(fmt.Sprintf("%s Downloading font list", m.spinner.View()))
+		return textStyle.Render(fmt.Sprintf("%s Downloading font list%s", m.spinner.View(), terminal.StartProgress()))
 	case selectFont:
-		return "\n" + m.list.View()
+		return fmt.Sprintf("\n%s%s", m.list.View(), terminal.StopProgress())
 	case downloadFont:
-		return textStyle.Render(fmt.Sprintf("%s Downloading %s", m.spinner.View(), m.font))
+		return textStyle.Render(fmt.Sprintf("%s Downloading %s%s", m.spinner.View(), m.font, terminal.StartProgress()))
 	case unzipFont:
 		return textStyle.Render(fmt.Sprintf("%s Extracting %s", m.spinner.View(), m.font))
 	case installFont:
 		return textStyle.Render(fmt.Sprintf("%s Installing %s", m.spinner.View(), m.font))
 	case quit:
-		return textStyle.Render("No need to install a new font? That's cool.")
+		return textStyle.Render(fmt.Sprintf("No need to install a new font? That's cool.%s", terminal.StopProgress()))
 	case done:
 		var builder strings.Builder
-		builder.WriteString(fmt.Sprintf("Successfully installed %s 🚀\n\n", m.font))
-		builder.WriteString("The following font families are now available for configuration:\n")
-		for _, family := range m.families {
-			builder.WriteString(fmt.Sprintf("  • %s\n", family))
+
+		builder.WriteString(fmt.Sprintf("Successfully installed %s 🚀\n\n%s", m.font, terminal.StopProgress()))
+		builder.WriteString("The following font families are now available for configuration:\n\n")
+
+		for i, family := range m.families {
+			builder.WriteString(fmt.Sprintf("  • %s", family))
+
+			if i < len(m.families)-1 {
+				builder.WriteString("\n")
+			}
 		}
+
 		return textStyle.Render(builder.String())
 	}
+
 	return ""
 }
 
-func Run(font string, system bool) {
+func Run(font string, ch cache_.Cache, root, ttf bool) {
 	main := &main{
 		font:   font,
-		system: system,
+		system: root,
+		ttf:    ttf,
 	}
+
+	cache = ch
+
 	program = tea.NewProgram(main)
 	if _, err := program.Run(); err != nil {
 		print("Error running program: %v", err)
