@@ -7,7 +7,12 @@ import (
 	"bytes"
 	"io"
 	"path"
+	stdruntime "runtime"
+	"slices"
 	"strings"
+
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime/cmd"
 )
 
 func contains[S ~[]E, E comparable](s S, e E) bool {
@@ -16,10 +21,17 @@ func contains[S ~[]E, E comparable](s S, e E) bool {
 			return true
 		}
 	}
+
 	return false
 }
 
-func InstallZIP(data []byte, user bool) ([]string, error) {
+func InstallZIP(data []byte, user, ttf bool) ([]string, error) {
+	// prefer OTF over TTF; otherwise prefer the first font we find
+	extension := ".otf"
+	if ttf {
+		extension = ".ttf"
+	}
+
 	var families []string
 	bytesReader := bytes.NewReader(data)
 
@@ -31,10 +43,17 @@ func InstallZIP(data []byte, user bool) ([]string, error) {
 	fonts := make(map[string]*Font)
 
 	for _, zf := range zipReader.File {
+		// prevent zipslip attacks
+		// https://security.snyk.io/research/zip-slip-vulnerability
+		if strings.Contains(zf.Name, "..") {
+			continue
+		}
+
 		rc, err := zf.Open()
 		if err != nil {
 			return families, err
 		}
+
 		defer rc.Close()
 
 		data, err := io.ReadAll(rc)
@@ -49,13 +68,14 @@ func InstallZIP(data []byte, user bool) ([]string, error) {
 
 		if _, found := fonts[fontData.Name]; !found {
 			fonts[fontData.Name] = fontData
-		} else {
-			// prefer OTF over TTF; otherwise prefer the first font we find
-			first := strings.ToLower(path.Ext(fonts[fontData.Name].FileName))
-			second := strings.ToLower(path.Ext(fontData.FileName))
-			if first != second && second == ".otf" {
-				fonts[fontData.Name] = fontData
-			}
+			continue
+		}
+
+		// respect the user's preference for TTF or OTF
+		first := strings.ToLower(path.Ext(fonts[fontData.Name].FileName))
+		second := strings.ToLower(path.Ext(fontData.FileName))
+		if first != second && second == extension {
+			fonts[fontData.Name] = fontData
 		}
 	}
 
@@ -64,10 +84,17 @@ func InstallZIP(data []byte, user bool) ([]string, error) {
 			return families, err
 		}
 
-		if !contains(families, font.Family) {
+		if found := contains(families, font.Family); !found {
 			families = append(families, font.Family)
 		}
 	}
 
+	// Update the font cache when installing fonts on Linux
+	if stdruntime.GOOS == runtime.LINUX || stdruntime.GOOS == runtime.DARWIN {
+		_, _ = cmd.Run("fc-cache", "-f")
+	}
+
+	slices.Sort(families)
+
 	return families, nil
 }
